@@ -4,11 +4,10 @@
 # This file is execfile()d with the current directory set to its containing dir.
 import os
 import sys
+from importlib.metadata import metadata
 
 sys.path[0:0] = [os.path.abspath("..")]
 
-from pymongo import version as pymongo_version  # noqa: E402
-
 import motor  # noqa: E402
 
 # -- General configuration -----------------------------------------------------
@@ -124,15 +123,20 @@ from motor import MotorClient
 
 html_copy_source = False
 
-# Theme gratefully vendored from CPython source.
-html_theme = "pydoctheme"
-html_theme_path = ["."]
-html_theme_options = {"collapsiblesidebar": True}
-html_static_path = ["static"]
+try:
+    import furo  # noqa: F401
 
-html_sidebars = {
-    "index": ["globaltoc.html", "searchbox.html"],
-}
+    html_theme = "furo"
+except ImportError:
+    # Theme gratefully vendored from CPython source.
+    html_theme = "pydoctheme"
+    html_theme_path = ["."]
+    html_theme_options = {"collapsiblesidebar": True}
+    html_static_path = ["static"]
+
+    html_sidebars = {
+        "index": ["globaltoc.html", "searchbox.html"],
+    }
 
 # The name for this set of Sphinx documents.  If None, it defaults to
 # "<project> v<release> documentation".
@@ -213,6 +217,7 @@ autodoc_default_options = {
     "member-order": "groupwise",
 }
 
+pymongo_version = metadata("pymongo")["version"]
 pymongo_inventory = ("https://pymongo.readthedocs.io/en/%s/" % pymongo_version, None)
 
 intersphinx_mapping = {
