@@ -133,7 +133,7 @@ class TestAsyncIOCursor(AsyncIOMockServerTestCase):
         self.assertTrue(cursor.next_object())
 
         # Not valid on server, causes CursorNotFound.
-        cursor.delegate._Cursor__id = bson.int64.Int64(1234)
+        cursor.delegate._id = bson.int64.Int64(1234)
 
         with self.assertRaises(OperationFailure):
             await cursor.fetch_next
@@ -192,7 +192,6 @@ class TestAsyncIOCursor(AsyncIOMockServerTestCase):
         self.assertEqual(expected(100, 101), (await cursor.to_list(1)))
         self.assertEqual(expected(101, 102), (await cursor.to_list(1)))
         self.assertEqual(expected(102, 103), (await cursor.to_list(1)))
-        self.assertEqual([], (await cursor.to_list(0)))
         self.assertEqual(expected(103, 105), (await cursor.to_list(2)))
 
         # Only 95 docs left, make sure length=100 doesn't error or hang
@@ -355,7 +354,7 @@ class TestAsyncIOCursor(AsyncIOMockServerTestCase):
 
         def canceled():
             try:
-                self.assertFalse(cursor.delegate._Cursor__killed)
+                self.assertFalse(cursor.delegate._killed)
                 self.assertTrue(cursor.alive)
 
                 # Resume iteration
@@ -586,7 +585,7 @@ class TestAsyncIOCursor(AsyncIOMockServerTestCase):
 
     @asyncio_test
     async def test_generate_keys(self):
-        c = self.collection
+        c = self.cx
         KMS_PROVIDERS = {"local": {"key": b"\x00" * 96}}
 
         async with motor_asyncio.AsyncIOMotorClientEncryption(
