@@ -20,7 +20,6 @@ import sys
 from functools import wraps
 from test.utils import create_user
 from test.version import Version
-from typing import TYPE_CHECKING
 from unittest import SkipTest
 
 import pymongo.errors
@@ -51,12 +50,7 @@ except ImportError:
 
 HAVE_AIOHTTP = True
 try:
-    # Remove when we drop support for 3.7
-    if TYPE_CHECKING:
-        HAVE_AIOHTTP = False
-        aiohttp = None
-    else:
-        import aiohttp
+    import aiohttp
 except ImportError:
     HAVE_AIOHTTP = False
     aiohttp = None
