@@ -17,15 +17,13 @@
 import copy
 import threading
 import time
+from test import SkipTest, env
+from test.tornado_tests import MotorTest
+from test.utils import get_async_test_timeout, wait_until
 
 from pymongo.errors import InvalidOperation, OperationFailure
 from tornado.testing import gen_test
 
-from test import SkipTest, env
-from test.tornado_tests import MotorTest
-from test.py35utils import wait_until
-from test.utils import get_async_test_timeout
-
 
 class MotorChangeStreamTest(MotorTest):
     @classmethod
@@ -37,7 +35,7 @@ class MotorChangeStreamTest(MotorTest):
 
         # Ensure the collection exists.
         env.sync_cx.motor_test.test_collection.delete_many({})
-        env.sync_cx.motor_test.test_collection.insert_one({'_id': 1})
+        env.sync_cx.motor_test.test_collection.insert_one({"_id": 1})
 
     def wait_and_insert(self, change_stream, n=1):
         # The start time of the change stream is nondeterministic. Wait
@@ -80,35 +78,34 @@ class MotorChangeStreamTest(MotorTest):
         self.assertIsNone(doc)
 
         # Insert a change and ensure we see it via try_next.
-        idoc = {'_id': 1, 'data': 'abc'}
+        idoc = {"_id": 1, "data": "abc"}
         self.wait_and_insert(change_stream, [idoc])
         while change_stream.alive:
             change_doc = await change_stream.try_next()
             if change_doc is not None:
                 break
-        self.assertEqual(change_doc['fullDocument'], idoc)
+        self.assertEqual(change_doc["fullDocument"], idoc)
 
     @env.require_version_min(4, 0, 7)
     @gen_test
     async def test_async_try_next_updates_resume_token(self):
-        change_stream = self.collection.watch(
-            [{"$match": {"fullDocument.a": 10}}])
+        change_stream = self.collection.watch([{"$match": {"fullDocument.a": 10}}])
 
         # Get empty change, check non-empty resume token.
         _ = await change_stream.try_next()
         self.assertIsNotNone(change_stream.resume_token)
 
         # Insert some record that don't match the change stream filter.
-        self.wait_and_insert(change_stream, [{'a': 19}, {'a': 20}])
+        self.wait_and_insert(change_stream, [{"a": 19}, {"a": 20}])
 
         # Ensure we see a new resume token even though we see no changes.
         initial_resume_token = copy.copy(change_stream.resume_token)
+
         async def token_change():
             _ = await change_stream.try_next()
             return change_stream.resume_token != initial_resume_token
 
-        await wait_until(token_change, "see a new resume token",
-                         timeout=get_async_test_timeout())
+        await wait_until(token_change, "see a new resume token", timeout=get_async_test_timeout())
 
     @gen_test
     async def test_watch(self):
@@ -125,9 +122,9 @@ class MotorChangeStreamTest(MotorTest):
         change = await future
 
         # New change stream with resume token.
-        await coll.insert_one({'_id': 23})
-        change = await coll.watch(resume_after=change['_id']).next()
-        self.assertEqual(change['fullDocument'], {'_id': 23})
+        await coll.insert_one({"_id": 23})
+        change = await coll.watch(resume_after=change["_id"]).next()
+        self.assertEqual(change["fullDocument"], {"_id": 23})
 
     @env.require_version_min(4, 2)
     @gen_test
@@ -136,22 +133,24 @@ class MotorChangeStreamTest(MotorTest):
         await self.collection.insert_one({})
 
         # Create change stream before invalidate event.
-        change_stream = self.collection.watch(
-            [{'$match': {'operationType': 'invalidate'}}])
+        change_stream = self.collection.watch([{"$match": {"operationType": "invalidate"}}])
         _ = await change_stream.try_next()
 
         # Generate invalidate event and store corresponding resume token.
         await self.collection.drop()
         _ = await change_stream.next()
+        # v5.1 requires an extra getMore after an invalidate event to exhaust
+        # the cursor.
+        self.assertIsNone(await change_stream.try_next())
         self.assertFalse(change_stream.alive)
         resume_token = change_stream.resume_token
 
         # Recreate change stream and observe from invalidate event.
-        doc = {'_id': 'startAfterTest'}
+        doc = {"_id": "startAfterTest"}
         await self.collection.insert_one(doc)
         change_stream = self.collection.watch(start_after=resume_token)
         change = await change_stream.next()
-        self.assertEqual(doc, change['fullDocument'])
+        self.assertEqual(doc, change["fullDocument"])
 
     @gen_test
     async def test_close(self):
@@ -171,7 +170,7 @@ class MotorChangeStreamTest(MotorTest):
     @gen_test
     async def test_missing_id(self):
         coll = self.collection
-        change_stream = coll.watch([{'$project': {'_id': 0}}])
+        change_stream = coll.watch([{"$project": {"_id": 0}}])
         future = change_stream.next()
         self.wait_and_insert(change_stream)
         with self.assertRaises((InvalidOperation, OperationFailure)):
@@ -239,3 +238,15 @@ class MotorChangeStreamTest(MotorTest):
             i += 1
             if i == 3:
                 break
+
+    @gen_test
+    async def test_watch_with_session(self):
+        async with await self.cx.start_session() as session:
+            # Pass MotorSession.
+            async with self.collection.watch(session=session) as cs:
+                self.wait_and_insert(cs, 1)
+                _ = await cs.next()
+            # Pass PyMongo session directly.
+            async with self.collection.watch(session=session.delegate) as cs:
+                self.wait_and_insert(cs, 1)
+                _ = await cs.next()
