@@ -14,67 +14,66 @@
 
 """Test replica set MotorClient."""
 
+import test
 import unittest
+from test import SkipTest
+from test.test_environment import env
+from test.tornado_tests import MotorReplicaSetTestBase, MotorTest
 
 import pymongo
 import pymongo.auth
 import pymongo.errors
-import pymongo.mongo_replica_set_client
 from tornado import gen
 from tornado.testing import gen_test
 
 import motor
 import motor.core
-import test
-from test import SkipTest
-from test.test_environment import db_user, db_password, env
-from test.tornado_tests import MotorReplicaSetTestBase, MotorTest
-from test.utils import one, get_primary_pool
 
 
 class MotorReplicaSetTest(MotorReplicaSetTestBase):
     def test_io_loop(self):
         with self.assertRaises(TypeError):
-            motor.MotorClient(test.env.rs_uri, io_loop='foo')
+            motor.MotorClient(test.env.rs_uri, io_loop="foo")
 
     @gen_test
     async def test_connection_failure(self):
         # Assuming there isn't anything actually running on this port
         client = motor.MotorClient(
-            'localhost:8765', replicaSet='rs', io_loop=self.io_loop,
-            serverSelectionTimeoutMS=10)
+            "localhost:8765", replicaSet="rs", io_loop=self.io_loop, serverSelectionTimeoutMS=10
+        )
 
         # Test the Future interface.
         with self.assertRaises(pymongo.errors.ConnectionFailure):
-            await client.admin.command('ismaster')
+            await client.admin.command("ismaster")
 
     @gen_test
     async def test_open_concurrent(self):
         # MOTOR-66: don't block on PyMongo's __monitor_lock, but also don't
         # spawn multiple monitors.
         c = self.motor_rsc()
-        await gen.multi(
-            [c.db.collection.find_one(), c.db.collection.find_one()])
+        await gen.multi([c.db.collection.find_one(), c.db.collection.find_one()])
 
 
 class TestReplicaSetClientAgainstStandalone(MotorTest):
     """This is a funny beast -- we want to run tests for a replica set
     MotorClient but only if the database at DB_IP and DB_PORT is a standalone.
     """
+
     def setUp(self):
         super().setUp()
         if test.env.is_replica_set:
-            raise SkipTest(
-                "Connected to a replica set, not a standalone mongod")
+            raise SkipTest("Connected to a replica set, not a standalone mongod")
 
     @gen_test
     async def test_connect(self):
         with self.assertRaises(pymongo.errors.ServerSelectionTimeoutError):
             await motor.MotorClient(
-                '%s:%s' % (env.host, env.port), replicaSet='anything',
+                "%s:%s" % (env.host, env.port),
+                replicaSet="anything",
                 io_loop=self.io_loop,
-                serverSelectionTimeoutMS=10).test.test.find_one()
+                serverSelectionTimeoutMS=10,
+            ).test.test.find_one()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
